@@ -21,7 +21,7 @@ def check_user(main: Mcdbot, user: Union[Member, User]):
         logger.debug(f"Member {user} is a member.")
         return True
 
-    member = main.main_guild.get_member(str(user.id))
+    member = main.get_main_guild().get_member(user.id)
     logger.debug(f"User {user} is Member {member}.")
     if member is not None:
         return True
