@@ -125,8 +125,7 @@ class Mcdbot(discord.Client):
         logger.remove(self.logger_id)
         logger.add(global_config.mcdbot_log, level="DEBUG", backtrace=True, diagnose=True, catch=False)
 
-    @property
-    def main_guild(self):
+    def get_main_guild(self):
         return self.get_guild(global_config.main_guild_id)
 
     # @tasks.loop(minutes=global_config.chore_loop_time)
@@ -143,7 +142,7 @@ class Mcdbot(discord.Client):
         logger.critical(f"EXCEPTION INFO: TIME = {now}; event_method = {event_method};"
                         f" args = {args}; kwargs = {kwargs}")
         try:
-            admin_role_mention = discord.utils.get(self.main_guild.roles,
+            admin_role_mention = discord.utils.get(self.get_main_guild().roles,
                                                    id=global_config.admin_role_id).mention
             main_channel = self.get_channel(global_config.main_channel_id)
             await main_channel.send(
